[![申请试用](https://image.joinquant.com/ab095497579621a92dc552f0507436d0)](https://www.joinquant.com/default/index/sdk)

# 公司介绍

**JoinQuant 聚宽，除为行业提供专业量化投研平台、本地数据服务等专业量化系统服务及工具支持，且是一家基于国内金融市场大数据，通过量化研究、人工智能等技术，不断挖掘规律、优化算法、精益模型，开展量化投资的资管公司。**

北京小龙虾科技有限公司成立于2015年，公司专注提供量化投研相关IT解决方案，为量化爱好者量身打造了聚宽量化投研平台（JoinQuant平台）, 提供全面的投研数据、易用的策略研究环境、精准的回测/模拟交易引擎、活跃的量化交流社区，便于用户快速实现、使用自己的量化策略。

**聚宽投研平台**（[www.JoinQuant.com](https://www.joinquant.com)）现有近50万个人及机构注册用户，凭借先进的量化投研技术，获得国家高新技术企业、北京专精特新企业、中关村高新技术企业等多项荣誉认证。

**聚宽投资**（[JoinQuant Investment](https://www.joinquant.com/view/algorithm/fundraising)）资产管理规模近百亿人民币，多次获得中国私募金牛奖、英华奖、金长江奖等行业殊荣，并经中基协认证，获得投顾资格。

（中基协登记编号：P1066435）。

**聚宽数据**（[JQData](https://www.joinquant.com/help/api/doc?name=JQDatadoc)）及算法交易（Alpha-T）长期为约30家大中型券商、超4000家量化机构提供专业服务。



# 产品介绍

## 1、产品定位

- **全生态验证体系**：

  **✓ **聚宽工程师团队专项维护，数据清洗标准贯穿自营资管与对外服务

  **✓** 历经「三位一体」验证：
      →  40万+策略开发者验证
      →  百亿级基金管理实战
      →  年均万亿交易量压力测试

- **多维度服务矩阵：**
  ✔ 轻量化API架构：5ms级响应速度，资源占用降低65%
  ✔ 跨领域赋能：覆盖金融机构风控建模、学术机构数据研究、量化私募因子开发三大场景
  ✔ 内生式进化：数据模型同步驱动聚宽平台/JQDatasdk/资管中台等核心业务迭代



## 2、为什么选择JQData

**低门槛本地化调用部署**：

- 全平台兼容：完美支持Windows/Mac/Linux系统

- 极简安装：三行Python指令完成部署

- 私有化部署：构建专属量化研究环境，突破云端平台限制

**专业级数据清洗维护：**

-  投研级处理：基于聚宽百亿级资管实战经验，通过：

-  多维度数据清洗框架

- 行业标准化字段封装

- 量化场景适配优化，打造符合专业研究习惯的数据体系

- 节省因数据问题带来的校验复核与修正精力

**极简的调用体验：**

- 丰富详细的API使用文档，且提供直接运行的代码实例

- 智能接口设计：
  **√** 跨品种统一API（如get_price支持全市场标的）
  **√** 相比传统数据商减少70%接口学习成本
  **√** 逻辑化数据聚合，告别多表查询困扰



## **3、JQData的稳定保障**

**JQData精准度**：

聚宽技术团队研发了信息监控系统和多信息源比对系统，通过一整套系统化的机制保证信息服务的准确性。且截至目前，聚宽自营基金管理规模已达百亿，使用聚宽JQData，其精准度满足量化交易的研究需求。

- 实时监控系统：秒级异常响应

- 多源比对引擎：7×24小时交叉验证

- 百亿级实盘验证：聚宽自营基金实战检验

**JQData稳定性**：

机房部署在阿里云，启用了多台服务器的数据交叉验证并设置备用，且提供独立的信息服务，采用负载均衡、高可用服务架构，配备完善的灾备体系，保证业务系统24小时不中断，并支持海量用户同时在线。数据传输方面，采用RPC协议传输，并压缩成特有数据格式，减少传输数据量，更加节省带宽。

- **基础设施**：
  **✓** 阿里云机房部署，提高硬件稳定性
  **✓** 分布式服务器集群
  **✓** 智能负载均衡系统
  **✓** 同城双活+异地灾备

- **传输优化**：
  ✔ RPC协议+专属压缩算法（带宽节省40%+）
  ✔ 支持10万数据量级并发访问



## **4、数据分类（JQData提供哪些数据）**

目前JQData提供的信息服务已基本覆盖国内所有可于二级市场交易的品种，量价信息支持年，月，周，分钟甚至秒级（Tick）等各频率的bar数据，除量价信息外，更配套各个市场的基础研究数据，包括但不限于品种信息各类衍生指标等；

聚宽基于量化研究经验，研发提供Alpha因子，技术指标，聚宽因子以及分钟资金流等特色因子，并结合股票组合需求提供CNE5及CNE6等风险模型，助力量化科学投资模型。

更多数据及接口详情可查看[聚宽JQDataAPI文档](https://www.joinquant.com/help/api/doc?name=JQDatadoc)，内含JQData提供的数据接口以及接口详细的更新时间



# 申请试用

- 申请链接：https://www.joinquant.com/default/index/sdk
- 申请方法：如实填写资料后提交
- 试用规则: https://www.joinquant.com/help/api/doc?name=logon&id=9830


# 调用方法

### 安装方法

```shell
# 首次安装
pip install jqdatasdk

# 升级版本
pip install -U jqdatasdk
```

超详细安装指引： https://www.joinquant.com/view/community/detail/cdf86c624992fc86ed51d920ef8c637b

### 使用方法

```python
import jqdatasdk

# 登录认证
jqdatasdk.auth(username, password) #即官网注册的账号及密码

# 获取数据
jqdatasdk.get_price("000001.XSHE", start_date="2017-01-01", end_date="2017-12-31")
```

详细的使用说明文档见：[https://www.joinquant.com/help/api/doc?name=JQDatadoc](https://www.joinquant.com/help/api/doc?name=JQDatadoc)

# 购买方式

请[点击此处获取购买方式](https://www.joinquant.com/help/api/doc?name=logon&id=9831)







